﻿module("VOICE")

local rr = {
	L"^%d",
	L"%d$",
	L"(%d+)",
	L"%d+",
	L"^[0-9]",
	L"[0-9]$",
	L"([0-9]+)",
	L"[0-9]+",
}

local tt = { 
	L"Поварская улица",
	L"Поварская улица 1",
	L"1я поварская улица",
	L"1-я поварская улица",
}

local function log(str, r)
	local b = wstring.find(str, r)
	voice_debug_log(L"TTS: tests " .. r .. L" => " .. towstring(tostring(b)), 3)
end

local function tests(str)
	voice_debug_log(L"TTS: tests " .. L" >> " .. str, 3)
	for i = 1, #rr do
		log(str, rr[i])
	end
	voice_debug_log(L"TTS: tests ## " .. format_all_numbers2text(str), 3)
end

function format_all_numbers2text_x(str, spell)
	return wstring.gsub(str, L"(%d+)", function(s)
		local inner = L""
		if #s > 3 or wstring.find(s, L"^0") or spell then
			for i = 1, #s do
				inner = inner .. format_numbers2text_x(tonumber(wstring.sub(s, i, i)))
			end
		else
			inner = format_numbers2text(tonumber(s))
		end
		return inner .. L" "
	end)
end

local function format_numbers2text_x(number)
	local index = {
		{39,9,43,49,33,53,37,4,13},
		{14,8,42,38,32,52,36,3,12},
		{25,5,40,47,30,50,34,1,10,14,26,7,41,48,31,51,35,2,11}
	}
	local str = towstring(number)
	if #str > 3 then return L" " .. str end
	if str == L"0" then return L" ноль" end
	local t = {}
	local out = L""
	for i = 1, #str do
		table.insert(t, tonumber(wstring.sub(str, i, i)))
	end
	for i = 1, (3 - #str) do
		table.insert(t, 1, 0)
	end
	if (10 * t[2] + t[3]) < 20 then
		t[3] = 10 * t[2] + t[3]
		t[2] = 0
	end
	for i = 1, #t do
		if t[i] then
			out = out .. L" " .. distances.patterns[index[i][t[i]]]
		end
	end
	return out
end


local function run_tests()
	for i = 1, #tt do
		tests(tt[i])
	end
	
	str = L"АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ"
	voice_debug_log(L"TTS: tests %d " .. str, 3)
	voice_debug_log(L"TTS: tests %d " .. format_all_numbers2text_x(str), 3)
	
	str = L"абвгдеёжзийклмнопрстуфхцчшщъыьэюя"
	voice_debug_log(L"TTS: tests %d " .. str, 3)
	voice_debug_log(L"TTS: tests %d " .. format_all_numbers2text_x(str), 3)
end



voice_debug_log(L"TTS: tests 1 start =========================", 3)
run_tests()
voice_debug_log(L"TTS: tests 1 end =========================", 3)

